@@ -7,7 +7,8 @@ import asyncio
 import json
 import logging
 import time
-from typing import Any, Dict, List, Mapping, Optional, Tuple
+from collections.abc import Iterable
+from typing import Any, Dict, List, Mapping, Tuple
 
 import aiohttp
 
@@ -151,8 +152,8 @@ class Mesh:
         self,
         node: str,
         password: str,
-        request_timeout: Optional[int] = 10,
-        session: Optional[aiohttp.ClientSession] = None,
+        request_timeout: int = 10,
+        session: aiohttp.ClientSession | None = None,
         username: str = "admin",
     ) -> None:
         """Initialise the Mesh.
@@ -217,8 +218,8 @@ class Mesh:
     async def _async_make_request(
         self,
         action: str,
-        node_address: Optional[str] = None,
-        payload: Optional[List[Dict] | Dict] = None,
+        node_address: str | None = None,
+        payload: List[Dict] | Dict | None = None,
         raise_on_error: bool = True,
     ) -> Tuple(api.Request, api.Response):
         """Execute the API request against the connected node.
@@ -417,7 +418,7 @@ class Mesh:
         )
 
         # region #-- prepare all the raw details --#
-        def _set_raw_value(action: str, data: Optional[List[Dict] | Dict]) -> None:
+        def _set_raw_value(action: str, data: List[Dict] | Dict | None) -> None:
             """Set the raw values"""
             try:
                 api_response: api.Response = api.Response(action=action, data=data)
@@ -483,7 +484,7 @@ class Mesh:
             if isinstance(node, Node):
                 # region #-- calculate the connected devices for nodes --#
                 connected_devices: List = []
-                parent_name: Optional[str] = None
+                parent_name: str | None = None
                 for device in devices:
                     for adapter in device.network:
                         if adapter.get("parent_id") == node.unique_id:
@@ -509,7 +510,7 @@ class Mesh:
                 attrib_connections = getattr(node, "_attribs", {}).get(
                     "connections", []
                 )
-                parent: Optional[str] = None
+                parent: str | None = None
                 for conn in attrib_connections:
                     if conn.get("parentDeviceID", ""):
                         try:
@@ -706,16 +707,20 @@ class Mesh:
         return resp.get(ATTR_CHANNEL_SCAN_INFO)
 
     async def async_get_device_from_id(
-        self, device_id: str, force_refresh: bool = False
-    ) -> Device | Node:
+        self,
+        device_id: Iterable[str],
+        force_refresh: bool = False,
+        raise_for_missing: bool = True,
+    ) -> List[Device | Node]:
         """Get a Device or Node object based on the ID.
 
         By default, the stored information is used, but you can refresh it from the API.
         Raises an error if the device is not found.
 
-        :param device_id: The ID of the device to get details about
+        :param device_id: Iterable of device IDs to get details about
         :param force_refresh: True to re-query the API for the latest details
-        :return: Device or Node object whichever is applicable
+        :param raise_for_missing: True to raise an error when a device is not found
+        :return: List of Device or Node objects whichever is applicable
         """
         _LOGGER.debug(
             self._log_formatter.format("entered, device_id: %s, force_refresh: %s"),
@@ -735,16 +740,21 @@ class Mesh:
         if not all_devices:
             raise MeshInvalidOutput from None
 
-        try:
-            ret = [device for device in all_devices if device.unique_id == device_id][0]
-        except IndexError as err:
-            raise MeshDeviceNotFoundResponse from err
+        ret = [device for device in all_devices if device.unique_id in device_id]
+        if len(ret) != len(device_id) and raise_for_missing:
+            found_ids = [device.unique_id for device in ret]
+            raise MeshDeviceNotFoundResponse(
+                devices=list(set(device_id).difference(found_ids))
+            )
 
         _LOGGER.debug(self._log_formatter.format("exited"))
         return ret
 
     async def async_get_device_from_mac_address(
-        self, mac_address: str, force_refresh: bool = False
+        self,
+        mac_address: Iterable[str],
+        force_refresh: bool = False,
+        raise_for_missing: bool = True,
     ) -> Device | Node:
         """To get a Device or Node object based on the MAC address.
 
@@ -752,8 +762,9 @@ class Mesh:
         By default, the stored information is used, but you can refresh it from the API.
         Raises an error if the device is not found.
 
-        :param mac_address: The MAC address to search for
+        :param mac_address: An iterable containing MAC address to search for
         :param force_refresh: True to re-query the details from the API
+        :param raise_for_missing: True to raise exception when a device is not found
         :return:  Device or Node object whichever is applicable
         """
         _LOGGER.debug(
@@ -762,7 +773,9 @@ class Mesh:
             force_refresh,
         )
 
-        ret: Optional[Device | Node] = None
+        ret: List[Device | Node] = []
+        lower_macs: List[str] = list(map(str.lower, mac_address))
+        found_macs: List[str] = []
 
         all_devices: List[Device | Node]
         if not force_refresh:
@@ -776,12 +789,15 @@ class Mesh:
         for device in all_devices:
             if device.network:
                 for adapter in device.network:
-                    if adapter.get("mac").lower() == mac_address.lower():
-                        ret = device
+                    if adapter.get("mac").lower() in lower_macs:
+                        ret.append(device)
+                        found_macs.append(adapter.get("mac").lower())
                         break
 
-        if not ret:
-            raise MeshDeviceNotFoundResponse
+        if len(ret) != len(mac_address) and raise_for_missing:
+            raise MeshDeviceNotFoundResponse(
+                devices=list(set(lower_macs).difference(found_macs))
+            )
 
         _LOGGER.debug(self._log_formatter.format("exited"))
         return ret
@@ -1058,7 +1074,7 @@ class Mesh:
 
     @property
     @needs_gather_details
-    def firmware_update_setting(self) -> Optional[str]:
+    def firmware_update_setting(self) -> str | None:
         """Get the current setting for firmware updates.
 
         :return: a lowercase string representing the update method
@@ -1125,7 +1141,7 @@ class Mesh:
 
     @property
     @needs_gather_details
-    def latest_speedtest_result(self) -> Optional[Dict]:
+    def latest_speedtest_result(self) -> Dict | None:
         """Get the Speedtest results.
 
         N.B. If you need more results see the async_get_speedtest_results method
@@ -1200,12 +1216,12 @@ class Mesh:
 
     @property
     @needs_gather_details
-    def parental_control_enabled(self) -> Optional[bool]:
+    def parental_control_enabled(self) -> bool | None:
         """Get the state of the Parental Control feature.
 
         :return: True if enabled, False if not
         """
-        ret: Optional[bool] = None
+        ret: bool | None = None
         if ATTR_PARENTAL_CONTROL_INFO in self._mesh_attributes:
             ret = self._mesh_attributes[ATTR_PARENTAL_CONTROL_INFO].get(
                 "isParentalControlEnabled", False
@@ -1252,7 +1268,7 @@ class Mesh:
                             for adapter in node[0].connected_adapters
                             if adapter.get("ip")
                         ]
-                        used_percent: Optional[int] = None
+                        used_percent: int | None = None
                         try:
                             used_percent = round(
                                 (partition.get("usedKB") / partition.get("availableKB"))
@@ -1306,7 +1322,7 @@ class Mesh:
 
     @property
     @needs_gather_details
-    def wan_ip(self) -> Optional[str]:
+    def wan_ip(self) -> str | None:
         """Get the WAN IP address.
 
         :return: A string containing the IP address for the WAN
@@ -1319,7 +1335,7 @@ class Mesh:
 
     @property
     @needs_gather_details
-    def wan_mac(self) -> Optional[str]:
+    def wan_mac(self) -> str | None:
         """Get the WAN MAC.
 
         :return: A string containing the MAC address for the WAN adapter
